@@ -6,6 +6,7 @@ import itertools
 import sys
 
 from boto.ec2 import connect_to_region
+from boto.exception import EC2ResponseError
 from boto.ec2.autoscale import AutoScaleConnection
 from fabric.api import run, sudo
 from fabric.contrib.project import rsync_project
@@ -85,6 +86,9 @@ def get_asg_hosts(args, dna_path):
     if not args.regions:
         return
 
+    if not args.aws_access_key_id or not args.aws_secret_access_key:
+        return
+
     for region in args.regions:
         auto_scale_conn = AutoScaleConnection(args.aws_access_key_id, args.aws_secret_access_key)
         conn = connect_to_region(
@@ -94,7 +98,11 @@ def get_asg_hosts(args, dna_path):
         )
         for group in auto_scale_conn.get_all_groups():
             instance_ids = [i.instance_id for i in group.instances]
-            reservations = conn.get_all_instances(instance_ids)
+            try:
+                reservations = conn.get_all_instances(instance_ids)
+            except EC2ResponseError:
+                continue
+
             instances = [i for r in reservations for i in r.instances]
             for instance in instances:
                 name = '{0}_{1}'.format(group.name, instance.id)
